==> munit-runner-3.1.0-sources.jar: org/mule/munit/runner/model/builders/TestRunFilter.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner.model.builders;

import org.mule.munit.remote.api.configuration.RunConfiguration;
import org.mule.munit.runner.component.TestComponent;

import java.util.Collections;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;

/**
 * Given a {@Link MunitTestFlow} it validates if the test should be run, based of a list of names and a set of tags
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class TestRunFilter {

  public static final String NO_TAG_TOKEN = "NO_TAG";

  /**
   * Define if a test should be run
   * 
   * @param testComponent the test to be checked if it should be run
   * @param testNameList a list of test names
   * @param tags a list of tags
   * @return false if the test should not be run, true otherwise
   */
  public boolean shouldRunTest(TestComponent testComponent, List<RunConfiguration.Test> testNameList, Set<String> tags,
                               String suitePath) {
    return isTestInList(testComponent, testNameList, suitePath) && isTagInTest(testComponent, tags);
  }

  private boolean isTestInList(TestComponent testComponent, List<RunConfiguration.Test> testNameList, String suitePath) {
    if (null == testNameList || testNameList.isEmpty()) {
      return true;
    }
    return testNameList.stream()
        .anyMatch(map -> map.getSuite().equals(suitePath) && map.getName().equals(testComponent.getName()));
  }

  private boolean isTagInTest(TestComponent testFlow, Set<String> tags) {
    return tags == null || tags.isEmpty() || shouldRunWithNoTag(testFlow, tags)
        || tagsInCommon(testFlow.getTags(), tags);
  }

  private boolean tagsInCommon(Set<String> testTags, Set<String> userTags) {
    return !Collections.disjoint(toLowerCaseAndTrim(testTags), toLowerCaseAndTrim(userTags));
  }

  private Set<String> toLowerCaseAndTrim(Set<String> tags) {
    return tags.stream().map(StringUtils::lowerCase).map(String::trim).collect(Collectors.toSet());
  }

  private boolean shouldRunWithNoTag(TestComponent testFlow, Set<String> tags) {
    return testFlow.getTags().isEmpty() && tags.stream().anyMatch(tag -> tag.trim().equalsIgnoreCase(NO_TAG_TOKEN));
  }


}

==> munit-runner-3.3.2-sources.jar: org/mule/munit/runner/model/builders/TestRunFilter.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.runner.model.builders;

import org.mule.munit.remote.api.configuration.RunConfiguration;
import org.mule.munit.runner.component.TestComponent;

import java.util.Collections;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;

/**
 * Given a {@Link MunitTestFlow} it validates if the test should be run, based of a list of names and a set of tags
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class TestRunFilter {

  public static final String NO_TAG_TOKEN = "NO_TAG";

  /**
   * Define if a test should be run
   * 
   * @param testName the test to be checked if it should be run
   * @param testNameList a list of test names
   * @param tags a list of tags
   * @return false if the test should not be run, true otherwise
   */
  public boolean shouldRunTest(String testName, Set<String> testTags, List<RunConfiguration.Test> testNameList, Set<String> tags,
                               String suitePath) {
    return isTestInList(testName, testNameList, suitePath) && isTagInTest(testTags, tags);
  }

  public boolean shouldRunTest(String testName, List<RunConfiguration.Test> testNameList, String suitePath) {
    return isTestInList(testName, testNameList, suitePath);
  }

  /**
   * Define if a test should be run
   * 
   * @param testComponent the test to be checked if it should be run
   * @param testNameList  a list of test names
   * @param tags          a list of tags
   * @return false if the test should not be run, true otherwise
   */
  public boolean shouldRunTest(TestComponent testComponent, List<RunConfiguration.Test> testNameList, Set<String> tags,
                               String suitePath) {
    return isTestInList(testComponent.getName(), testNameList, suitePath) && isTagInTest(testComponent.getTags(), tags);
  }

  private boolean isTestInList(String testName, List<RunConfiguration.Test> testNameList, String suitePath) {
    if (null == testNameList || testNameList.isEmpty()) {
      return true;
    }
    return testNameList.stream()
        .anyMatch(map -> map.getSuite().equals(suitePath) && map.getName().equals(testName));
  }

  private boolean isTagInTest(Set<String> testTags, Set<String> tags) {
    return tags == null || tags.isEmpty() || shouldRunWithNoTag(testTags, tags)
        || tagsInCommon(testTags, tags);
  }

  private boolean tagsInCommon(Set<String> testTags, Set<String> userTags) {
    return !Collections.disjoint(toLowerCaseAndTrim(testTags), toLowerCaseAndTrim(userTags));
  }

  private Set<String> toLowerCaseAndTrim(Set<String> tags) {
    return tags.stream().map(StringUtils::lowerCase).map(String::trim).collect(Collectors.toSet());
  }

  private boolean shouldRunWithNoTag(Set<String> testTags, Set<String> tags) {
    return testTags.isEmpty() && tags.stream().anyMatch(tag -> tag.trim().equalsIgnoreCase(NO_TAG_TOKEN));
  }


}
